@@ -17,8 +17,7 @@
 
    You should have received a copy of the GNU Library General Public
    License along application the Gnome Library; see the file COPYING.LIB.  If not,
-   write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   see <http://www.gnu.org/licenses/>.
 
    Authors: Dave Camp <dave@novell.com>
 */
